####################################################################################
# Sample R script for reading NetCDF files in the Gonzalez et al. 2020 dataset
# Paula Gonzalez - UoR - Oct 2020
#


library(ncdf4)

# set work directory - change to match your location
setwd("/YOUR_DATASET_LOCATION/country_daily_demand/")

# test file
idir <- "./"
ifile <- "ecmwf_s2s_coun_demand_fcst_w_VI_and_rea_DAILY_stmon_01.nc"

# open NetCDF and read variables
test_nc <- nc_open(paste0(idir,ifile))
test_fcst <- ncvar_get(test_nc, "demand_fcst") # mems x days x years x countries
test_rea <- ncvar_get(test_nc, "demand_rea")
test_dates <- ncvar_get(test_nc, "date")
test_countries <- ncvar_get(test_nc, "country_codes")
  
# one way to create the dates array, reading the 'origin' from the units

time <- ncvar_get(test_nc,"date")
tunits <- ncatt_get(test_nc,"date",attname="units")
tustr <- strsplit(tunits$value, " ")
dates_array <- as.Date(time,origin=unlist(tustr)[3])


# an alternative way is just to impose the origin, which in this case is R's default date origin

dates_array2 <- as.Date(test_dates,origin = "1970-01-01")

# close NetCDF file

nc_close(test_nc)

# check that country codes can be read properly

test_countries
test_countries[28]

# check arrays dimensions

dim(test_fcst)          # ens members x start days x start years x lead days x countries
dim(test_rea)           # start days x start years x lead days x countries
dim(dates_array)        # start days x start years x lead days 
dim(test_countries)     # 28 countries
